@@ -1,67 +1,41 @@
 package Apache::Status;
 use strict;
-use vars qw($VERSION);
-
-$VERSION = (qw$Revision: 1.11 $)[1];
 
 my(%status) = (
    inc => "Loaded Modules",
    rgysubs => "Compiled Registry Scripts",
    symdump => "Symbol Table Dump",
-   inh_tree => "Inheritance Tree",
-   isa_tree => "ISA Tree",	       
 );
 
-sub menu_item {
-    my($self, $key, $val, $sub) = @_;
-    $status{$key} = $val;
-    no strict;
-    *{"status_${key}"} = $sub 
-	if $sub and ref $sub eq 'CODE';
-}
-
 sub handler {
     my($r) = @_;
-    Apache->request($r); #for Apache::CGI
+    require Apache::CGI;
+    my $q = new Apache::CGI;
     my $qs = $r->args;
     my $sub = "status_$qs";
+    $r->write_client($q->header, $q->start_html, $q->start_form);
     no strict 'refs';
-    $r->print(header());
     if(defined &$sub) {
-	$r->module('CGI::Switch');
-	$r->module('Devel::Symdump');
-	$r->print(@{ &{$sub}($r,CGI::Switch->new) });
+	$r->write_client(@{ &{$sub}($r,$q) });
     }
     elsif (exists $Apache::Registry->{$qs}) { 
-	$r->module('Devel::Symdump');
-	$r->print(symdump($qs));
+	$r->write_client(symdump($qs));
     }
     else {
 	my $uri = $r->uri;
-	$r->print(
+	my $start = scalar localtime $^T;
+	$r->write_client(
+            "Perl Status for process <b>$$</b>, running since $start<hr>\n",
  	    map { qq[<a href="$uri?$_">$status{$_}</a><br>\n] } keys %status
         );
     }
-    $r->print("</body></html>");
 
     1;
 }
 
-sub header {
-    my $start = scalar localtime $^T;    
-    my $srv = Apache::Constants::SERVER_VERSION();
-    return <<"EOF";
-<html>
-<head><title>Apache::Status</title></head>
-<body>
-Embedded Perl version <b>$]</b> for <b>$srv</b> process <b>$$</b>, 
-<br> running since $start<hr>
-EOF
-
-}
-
 sub symdump {
     my($package) = @_;
+    require Devel::Symdump;
     my $sob = Devel::Symdump->rnew($package);
     return $sob->as_HTML($package);
 }
@@ -70,19 +44,15 @@ sub status_symdump { [symdump('main')] }
 
 sub status_inc {
     my($r,$q) = @_;
-    my(@retval, $module, $v);
+    my(@retval, $module);
+    local $_;
     foreach $module ($q->param("INC")) {
 	delete $INC{$module};
     }
     $q->delete("INC");
-    foreach $module (sort keys %INC) {
-	next unless $INC{$module}; #e.g. fake Apache/TieHandle.pm
-	no strict 'refs';
-	$module =~ s,/,::,g;
-	$module =~ s,\.pm$,,;
-	$v = ${"$module\:\:VERSION"} || '0.00';
+    foreach (sort keys %INC) {
 	push @retval, 
-	"$module ($v) <br>\n";
+	"$_ <br>\n";
 	#$q->checkbox(-name => "INC", -value => $_, -label => $_), "<br>";
     }
     push @retval, "<hr>"; #, $q->submit(-value => "Delete");
@@ -105,9 +75,6 @@ sub status_rgysubs {
     \@retval;
 }
 
-sub status_inh_tree { ["<pre>", Devel::Symdump->inh_tree, "</pre>"] }
-sub status_isa_tree { ["<pre>", Devel::Symdump->isa_tree, "</pre>"] }
-
 1;
 
 __END__
@@ -116,13 +83,6 @@ __END__
 
 Apache::Status - Embedded interpreter status information 
 
-=head1 SYNOPSIS
-
- <Location /perl-status>
- SetHandler  perl-script
- PerlHandler Apache::Status
- </Location>
-
 =head1 DESCRIPTION
 
 The B<Apache::Status> module provides some information
@@ -135,19 +95,6 @@ Configure like so:
  PerlHandler Apache::Status
  </Location>
 
-Other modules can "plugin" a menu item like so:
-
- Apache::Status->menu_item(
-    'DBI' => "DBI connections", #item for Apache::DBI module
-    sub {
-        my($r,$q) = @_; #request and CGI objects
-        my(@strings);
-        push @strings,  "blobs of html";
-        return \@s;     #return an array ref
-    }
- ) if Apache->module("Apache::Status"); #only if Apache::Status is loaded
-
-
 =head1 PREREQUISITES
 
 The I<Devel::Symdump> module must be installed:
